
# Slot: node_type_list_rows_to_skip


The number of lines to skip in the node types file. The header is already skipped if it has been specified that the file has an header.

URI: [https://w3id.org/neat/ensmallenRunConfig__node_type_list_rows_to_skip](https://w3id.org/neat/ensmallenRunConfig__node_type_list_rows_to_skip)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
